@@ -2,16 +2,13 @@
 
 
 package Proc::Swarm;
-{
-  $Proc::Swarm::VERSION = '1.133280';
-}
-
+$Proc::Swarm::VERSION = '1.161060';
 use strict;use warnings;
 use IPC::Msg;
 use Storable;
 
 sub _usage {
-    print @_ . "\n" if defined @_;
+    print @_ . "\n" if @_;
     print q(
 Proc::Swarm::swarm(
     code     => $coderef,
@@ -192,10 +189,7 @@ sub _worker_worker {
 } 
 
 package Proc::Swarm::Package;
-{
-  $Proc::Swarm::Package::VERSION = '1.133280';
-}
-
+$Proc::Swarm::Package::VERSION = '1.161060';
 sub new {
     my ($proto,$object,$type) = @_;
 
@@ -219,10 +213,7 @@ sub get_object {
     return $self->{obj};
 }
 package Proc::Swarm::Results;
-{
-  $Proc::Swarm::Results::VERSION = '1.133280';
-}
-
+$Proc::Swarm::Results::VERSION = '1.161060';
 sub new {
     my $proto = shift;
     my $class = ref($proto) || $proto;
@@ -295,10 +286,7 @@ sub get_objects {
 }
 
 package Proc::Swarm::Result;
-{
-  $Proc::Swarm::Result::VERSION = '1.133280';
-}
-
+$Proc::Swarm::Result::VERSION = '1.161060';
 sub new {
     my $proto = shift;
     my $class = ref($proto) || $proto;
@@ -334,10 +322,7 @@ sub get_result_type  {
 
 
 package Proc::Swarm::Queue;
-{
-  $Proc::Swarm::Queue::VERSION = '1.133280';
-}
-
+$Proc::Swarm::Queue::VERSION = '1.161060';
 sub new {
     my $proto = shift;
     my $class = ref($proto) || $proto;
@@ -476,7 +461,7 @@ intensive.  While not a bug, this can be rather alarming.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001, 2013 Dana M. Diederich. All Rights Reserved.
+Copyright (c) 2001, 2013, 2016 Dana M. Diederich. All Rights Reserved.
 This module is free software. It may be used, redistributed
 and/or modified under the terms of the Perl Artistic License
   (see http://www.perl.com/perl/misc/Artistic.html)
